@@ -9,7 +9,8 @@ var Handlebars = require('handlebars');
 var HtmlWebpackPlugin = require('html-webpack-plugin');
 var webpack = require('webpack');
 var DuplicatePackageCheckerPlugin = require('duplicate-package-checker-webpack-plugin');
-var Visualizer = require('webpack-visualizer-plugin');
+var BundleAnalyzerPlugin = require('webpack-bundle-analyzer')
+  .BundleAnalyzerPlugin;
 
 var Build = require('@jupyterlab/buildutils').Build;
 var WPPlugin = require('@jupyterlab/buildutils').WPPlugin;
@@ -138,7 +139,7 @@ const plugins = [
 ];
 
 if (process.argv.includes('--analyze')) {
-  plugins.push(new Visualizer());
+  plugins.push(new BundleAnalyzerPlugin());
 }
 
 module.exports = [
@@ -189,8 +190,22 @@ module.exports = [
         },
         { test: /\.eot(\?v=\d+\.\d+\.\d+)?$/, use: 'file-loader' },
         {
+          // in css files, svg is loaded as a url formatted string
           test: /\.svg(\?v=\d+\.\d+\.\d+)?$/,
-          use: 'url-loader?limit=10000&mimetype=image/svg+xml'
+          issuer: { test: /\.css$/ },
+          use: {
+            loader: 'svg-url-loader',
+            options: { encoding: 'none', limit: 10000 }
+          }
+        },
+        {
+          // in ts and tsx files (both of which compile to js),
+          // svg is loaded as a raw string
+          test: /\.svg(\?v=\d+\.\d+\.\d+)?$/,
+          issuer: { test: /\.js$/ },
+          use: {
+            loader: 'raw-loader'
+          }
         }
       ]
     },
